==> estateplat-common-1.2.3-20180427.083444-69-sources.jar: cn/gtmap/estateplat/model/commodityHouse/contract/FcjyXjspfBaYxsxk.java <==
package cn.gtmap.estateplat.model.commodityHouse.contract;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/*
 * @author <a href="mailto:zhangguangguang@gtmap.cn">zhangguangguang</a>
 * @version 1.0, 2018/04/20
 * @description 新建商品房预售许可历史表
 */
@Table(name = "fcjy_xjspf_ba_yxsxk")
public class FcjyXjspfBaYxsxk {
    @Id
    private String xklsid;//主键
    private String xkid;//新建商品房预售许可历史表主键
    private Long xkbh;//许可编号
    private String fdckfqymc;//房地产开发企业名称
    private Long fdckfqybh;//房地产开发企业编号
    private String xmid;//项目ID
    private Long xmbh;//项目编号
    private String xmmc;//项目名称
    private String fwzls;//房屋坐落市
    private String qxh;//区县号
    private String ysfw;//预售范围
    private Date fzrq;//发证日期
    private Date yxrq;//有效日期
    private Double yjjgmj;//预计竣工面积（平方米）
    private Integer yjjgts;//预计竣工套数
    private Date yjjgrq;//预计竣工日期
    private Double zjzmj;//总建筑面积（平方米）
    private Double xkmj;//许可面积（平方米）
    private Integer xkts;//许可套数
    private Date xsksrq;//销售开始日期
    private Date xsjsrq;//销售结束日期
    private Double pzyszfzmj;//批准预售住房总面积（平方米）
    private Double zfyssbpjjg;//住房预售申报平均价格（元/平方米）
    private Double pzyssyyyyfzmj;//批准预售商业营业用房总面积（平方米）
    private Double syyyyfyssbpjjg;//商业营业用房预售申报平均价格（元/平方米）
    private Double pzysbglzmj;//批准预售办公楼总面积（平方米）
    private Double bglyssbpjjg;//办公楼预售申报平均价格（元/平方米）
    private Double pzysqtfwzmj;//批准预售其他房屋总面积（平方米）
    private Double qtfwsbpjjg;//其他房屋申报平均价格（元/平方米）
    private String xkzh;//许可证号
    private String djjg;//登记机构
    private String sfzx;//0：未注销1：注销
    private String zxyy;//注销原因
    private String bz;//备注
    private String zt;//状态（状态字典表）
    private String sfdj;//是否冻结(0或空不是，1是)
    private String lx;//类型（YS：预售 XS：现售 ）
    private Date lssj;//历史时间
    private Integer lscs;//历史次数

    public String getXklsid() {
        return xklsid;
    }

    public void setXklsid(String xklsid) {
        this.xklsid = xklsid;
    }


    public String getXkid() {
        return xkid;
    }

    public void setXkid(String xkid) {
        this.xkid = xkid;
    }

    public Long getXkbh() {
        return xkbh;
    }

    public void setXkbh(Long xkbh) {
        this.xkbh = xkbh;
    }

    public String getFdckfqymc() {
        return fdckfqymc;
    }

    public void setFdckfqymc(String fdckfqymc) {
        this.fdckfqymc = fdckfqymc;
    }

    public Long getFdckfqybh() {
        return fdckfqybh;
    }

    public void setFdckfqybh(Long fdckfqybh) {
        this.fdckfqybh = fdckfqybh;
    }

    public String getXmid() {
        return xmid;
    }

    public void setXmid(String xmid) {
        this.xmid = xmid;
    }

    public Long getXmbh() {
        return xmbh;
    }

    public void setXmbh(Long xmbh) {
        this.xmbh = xmbh;
    }

    public String getXmmc() {
        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public String getFwzls() {
        return fwzls;
    }

    public void setFwzls(String fwzls) {
        this.fwzls = fwzls;
    }

    public String getQxh() {
        return qxh;
    }

    public void setQxh(String qxh) {
        this.qxh = qxh;
    }

    public String getYsfw() {
        return ysfw;
    }

    public void setYsfw(String ysfw) {
        this.ysfw = ysfw;
    }

    public Date getFzrq() {
        return fzrq;
    }

    public void setFzrq(Date fzrq) {
        this.fzrq = fzrq;
    }

    public Date getYxrq() {
        return yxrq;
    }

    public void setYxrq(Date yxrq) {
        this.yxrq = yxrq;
    }

    public Double getYjjgmj() {
        return yjjgmj;
    }

    public void setYjjgmj(Double yjjgmj) {
        this.yjjgmj = yjjgmj;
    }

    public Integer getYjjgts() {
        return yjjgts;
    }

    public void setYjjgts(Integer yjjgts) {
        this.yjjgts = yjjgts;
    }

    public Date getYjjgrq() {
        return yjjgrq;
    }

    public void setYjjgrq(Date yjjgrq) {
        this.yjjgrq = yjjgrq;
    }

    public Double getZjzmj() {
        return zjzmj;
    }

    public void setZjzmj(Double zjzmj) {
        this.zjzmj = zjzmj;
    }

    public Double getXkmj() {
        return xkmj;
    }

    public void setXkmj(Double xkmj) {
        this.xkmj = xkmj;
    }

    public Integer getXkts() {
        return xkts;
    }

    public void setXkts(Integer xkts) {
        this.xkts = xkts;
    }

    public Date getXsksrq() {
        return xsksrq;
    }

    public void setXsksrq(Date xsksrq) {
        this.xsksrq = xsksrq;
    }

    public Date getXsjsrq() {
        return xsjsrq;
    }

    public void setXsjsrq(Date xsjsrq) {
        this.xsjsrq = xsjsrq;
    }

    public Double getPzyszfzmj() {
        return pzyszfzmj;
    }

    public void setPzyszfzmj(Double pzyszfzmj) {
        this.pzyszfzmj = pzyszfzmj;
    }

    public Double getZfyssbpjjg() {
        return zfyssbpjjg;
    }

    public void setZfyssbpjjg(Double zfyssbpjjg) {
        this.zfyssbpjjg = zfyssbpjjg;
    }

    public Double getPzyssyyyyfzmj() {
        return pzyssyyyyfzmj;
    }

    public void setPzyssyyyyfzmj(Double pzyssyyyyfzmj) {
        this.pzyssyyyyfzmj = pzyssyyyyfzmj;
    }

    public Double getSyyyyfyssbpjjg() {
        return syyyyfyssbpjjg;
    }

    public void setSyyyyfyssbpjjg(Double syyyyfyssbpjjg) {
        this.syyyyfyssbpjjg = syyyyfyssbpjjg;
    }

    public Double getPzysbglzmj() {
        return pzysbglzmj;
    }

    public void setPzysbglzmj(Double pzysbglzmj) {
        this.pzysbglzmj = pzysbglzmj;
    }

    public Double getBglyssbpjjg() {
        return bglyssbpjjg;
    }

    public void setBglyssbpjjg(Double bglyssbpjjg) {
        this.bglyssbpjjg = bglyssbpjjg;
    }

    public Double getPzysqtfwzmj() {
        return pzysqtfwzmj;
    }

    public void setPzysqtfwzmj(Double pzysqtfwzmj) {
        this.pzysqtfwzmj = pzysqtfwzmj;
    }

    public Double getQtfwsbpjjg() {
        return qtfwsbpjjg;
    }

    public void setQtfwsbpjjg(Double qtfwsbpjjg) {
        this.qtfwsbpjjg = qtfwsbpjjg;
    }

    public String getXkzh() {
        return xkzh;
    }

    public void setXkzh(String xkzh) {
        this.xkzh = xkzh;
    }

    public String getDjjg() {
        return djjg;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    public String getSfzx() {
        return sfzx;
    }

    public void setSfzx(String sfzx) {
        this.sfzx = sfzx;
    }

    public String getZxyy() {
        return zxyy;
    }

    public void setZxyy(String zxyy) {
        this.zxyy = zxyy;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getZt() {
        return zt;
    }

    public void setZt(String zt) {
        this.zt = zt;
    }

    public String getSfdj() {
        return sfdj;
    }

    public void setSfdj(String sfdj) {
        this.sfdj = sfdj;
    }

    public String getLx() {
        return lx;
    }

    public void setLx(String lx) {
        this.lx = lx;
    }

    public Date getLssj() { return lssj;}

    public void setLssj(Date lssj) { this.lssj = lssj;}

    public Integer getLscs() { return lscs; }

    public void setLscs(Integer lscs) { this.lscs = lscs; }
}

==> estateplat-common-1.2.3-20180710.104808-145-sources.jar: cn/gtmap/estateplat/model/commodityHouse/contract/FcjyXjspfBaYxsxk.java <==
package cn.gtmap.estateplat.model.commodityHouse.contract;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/*
 * @author <a href="mailto:zhangguangguang@gtmap.cn">zhangguangguang</a>
 * @version 1.0, 2018/04/20
 * @description 新建商品房预售许可历史表
 */
@Table(name = "fcjy_xjspf_ba_yxsxk")
public class FcjyXjspfBaYxsxk implements Serializable {
    @Id
    private String xklsid;//主键
    private String xkid;//新建商品房预售许可历史表主键
    private Long xkbh;//许可编号
    private String fdckfqymc;//房地产开发企业名称
    private Long fdckfqybh;//房地产开发企业编号
    private String xmid;//项目ID
    private Long xmbh;//项目编号
    private String xmmc;//项目名称
    private String fwzls;//房屋坐落市
    private String qxh;//区县号
    private String ysfw;//预售范围
    private Date fzrq;//发证日期
    private Date yxrq;//有效日期
    private Double yjjgmj;//预计竣工面积（平方米）
    private Integer yjjgts;//预计竣工套数
    private Date yjjgrq;//预计竣工日期
    private Double zjzmj;//总建筑面积（平方米）
    private Double xkmj;//许可面积（平方米）
    private Integer xkts;//许可套数
    private Date xsksrq;//销售开始日期
    private Date xsjsrq;//销售结束日期
    private Double pzyszfzmj;//批准预售住房总面积（平方米）
    private Double zfyssbpjjg;//住房预售申报平均价格（元/平方米）
    private Double pzyssyyyyfzmj;//批准预售商业营业用房总面积（平方米）
    private Double syyyyfyssbpjjg;//商业营业用房预售申报平均价格（元/平方米）
    private Double pzysbglzmj;//批准预售办公楼总面积（平方米）
    private Double bglyssbpjjg;//办公楼预售申报平均价格（元/平方米）
    private Double pzysqtfwzmj;//批准预售其他房屋总面积（平方米）
    private Double qtfwsbpjjg;//其他房屋申报平均价格（元/平方米）
    private String xkzh;//许可证号
    private String djjg;//登记机构
    private String sfzx;//0：未注销1：注销
    private String zxyy;//注销原因
    private String bz;//备注
    private String zt;//状态（状态字典表）
    private String sfdj;//是否冻结(0或空不是，1是)
    private String lx;//类型（YS：预售 XS：现售 ）
    private Date lssj;//历史时间
    private Integer lscs;//历史次数

    public String getXklsid() {
        return xklsid;
    }

    public void setXklsid(String xklsid) {
        this.xklsid = xklsid;
    }


    public String getXkid() {
        return xkid;
    }

    public void setXkid(String xkid) {
        this.xkid = xkid;
    }

    public Long getXkbh() {
        return xkbh;
    }

    public void setXkbh(Long xkbh) {
        this.xkbh = xkbh;
    }

    public String getFdckfqymc() {
        return fdckfqymc;
    }

    public void setFdckfqymc(String fdckfqymc) {
        this.fdckfqymc = fdckfqymc;
    }

    public Long getFdckfqybh() {
        return fdckfqybh;
    }

    public void setFdckfqybh(Long fdckfqybh) {
        this.fdckfqybh = fdckfqybh;
    }

    public String getXmid() {
        return xmid;
    }

    public void setXmid(String xmid) {
        this.xmid = xmid;
    }

    public Long getXmbh() {
        return xmbh;
    }

    public void setXmbh(Long xmbh) {
        this.xmbh = xmbh;
    }

    public String getXmmc() {
        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public String getFwzls() {
        return fwzls;
    }

    public void setFwzls(String fwzls) {
        this.fwzls = fwzls;
    }

    public String getQxh() {
        return qxh;
    }

    public void setQxh(String qxh) {
        this.qxh = qxh;
    }

    public String getYsfw() {
        return ysfw;
    }

    public void setYsfw(String ysfw) {
        this.ysfw = ysfw;
    }

    public Date getFzrq() {
        return fzrq;
    }

    public void setFzrq(Date fzrq) {
        this.fzrq = fzrq;
    }

    public Date getYxrq() {
        return yxrq;
    }

    public void setYxrq(Date yxrq) {
        this.yxrq = yxrq;
    }

    public Double getYjjgmj() {
        return yjjgmj;
    }

    public void setYjjgmj(Double yjjgmj) {
        this.yjjgmj = yjjgmj;
    }

    public Integer getYjjgts() {
        return yjjgts;
    }

    public void setYjjgts(Integer yjjgts) {
        this.yjjgts = yjjgts;
    }

    public Date getYjjgrq() {
        return yjjgrq;
    }

    public void setYjjgrq(Date yjjgrq) {
        this.yjjgrq = yjjgrq;
    }

    public Double getZjzmj() {
        return zjzmj;
    }

    public void setZjzmj(Double zjzmj) {
        this.zjzmj = zjzmj;
    }

    public Double getXkmj() {
        return xkmj;
    }

    public void setXkmj(Double xkmj) {
        this.xkmj = xkmj;
    }

    public Integer getXkts() {
        return xkts;
    }

    public void setXkts(Integer xkts) {
        this.xkts = xkts;
    }

    public Date getXsksrq() {
        return xsksrq;
    }

    public void setXsksrq(Date xsksrq) {
        this.xsksrq = xsksrq;
    }

    public Date getXsjsrq() {
        return xsjsrq;
    }

    public void setXsjsrq(Date xsjsrq) {
        this.xsjsrq = xsjsrq;
    }

    public Double getPzyszfzmj() {
        return pzyszfzmj;
    }

    public void setPzyszfzmj(Double pzyszfzmj) {
        this.pzyszfzmj = pzyszfzmj;
    }

    public Double getZfyssbpjjg() {
        return zfyssbpjjg;
    }

    public void setZfyssbpjjg(Double zfyssbpjjg) {
        this.zfyssbpjjg = zfyssbpjjg;
    }

    public Double getPzyssyyyyfzmj() {
        return pzyssyyyyfzmj;
    }

    public void setPzyssyyyyfzmj(Double pzyssyyyyfzmj) {
        this.pzyssyyyyfzmj = pzyssyyyyfzmj;
    }

    public Double getSyyyyfyssbpjjg() {
        return syyyyfyssbpjjg;
    }

    public void setSyyyyfyssbpjjg(Double syyyyfyssbpjjg) {
        this.syyyyfyssbpjjg = syyyyfyssbpjjg;
    }

    public Double getPzysbglzmj() {
        return pzysbglzmj;
    }

    public void setPzysbglzmj(Double pzysbglzmj) {
        this.pzysbglzmj = pzysbglzmj;
    }

    public Double getBglyssbpjjg() {
        return bglyssbpjjg;
    }

    public void setBglyssbpjjg(Double bglyssbpjjg) {
        this.bglyssbpjjg = bglyssbpjjg;
    }

    public Double getPzysqtfwzmj() {
        return pzysqtfwzmj;
    }

    public void setPzysqtfwzmj(Double pzysqtfwzmj) {
        this.pzysqtfwzmj = pzysqtfwzmj;
    }

    public Double getQtfwsbpjjg() {
        return qtfwsbpjjg;
    }

    public void setQtfwsbpjjg(Double qtfwsbpjjg) {
        this.qtfwsbpjjg = qtfwsbpjjg;
    }

    public String getXkzh() {
        return xkzh;
    }

    public void setXkzh(String xkzh) {
        this.xkzh = xkzh;
    }

    public String getDjjg() {
        return djjg;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    public String getSfzx() {
        return sfzx;
    }

    public void setSfzx(String sfzx) {
        this.sfzx = sfzx;
    }

    public String getZxyy() {
        return zxyy;
    }

    public void setZxyy(String zxyy) {
        this.zxyy = zxyy;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getZt() {
        return zt;
    }

    public void setZt(String zt) {
        this.zt = zt;
    }

    public String getSfdj() {
        return sfdj;
    }

    public void setSfdj(String sfdj) {
        this.sfdj = sfdj;
    }

    public String getLx() {
        return lx;
    }

    public void setLx(String lx) {
        this.lx = lx;
    }

    public Date getLssj() { return lssj;}

    public void setLssj(Date lssj) { this.lssj = lssj;}

    public Integer getLscs() { return lscs; }

    public void setLscs(Integer lscs) { this.lscs = lscs; }
}
